@@ -8,7 +8,7 @@ use Padre::Wx   ();
 use base 'Padre::Plugin';
 
 # exports and version
-our $VERSION   = '0.49';
+our $VERSION   = '0.50';
 our @EXPORT_OK = qw(plugin_config);
 
 # constants for html exporting
@@ -344,13 +344,13 @@ sub show_perl6_doc {
 		my $line = $editor->GetLine($lineno);
 		my $current_pos = $editor->GetCurrentPos() - $editor->PositionFromLine($lineno);
 		my $current_word = '';
-		while( $line =~ m/\G.*?([[:alnum:]]+)/g ) {
+		while( $line =~ m/\G.*?(\S+)/g ) {
 			if(pos($line) >= $current_pos) {
 				$current_word = $1;
 				last;
 			}
 		}
-		if($current_word =~ /^.*?(\w+)/) {
+		if($current_word =~ /^.*?(\S+)/) {
 			$topic = $1;
 		}
 	}
